@@ -31,8 +31,12 @@ class LDMLogger():
                     Adding project.
                  def upload_dataset(self, path_to_dataset, dataset_type_in="Train"):
                     Uploads dataset to server.
+                def upload_sources(self):
+                    Creates a .zip of root_dir and uploads it to the LDM server.
                 def download_dataset(self, path="", dataset_type_in="Train"):
                     Downloads dataset from server.
+                def save_colab_notebook_history_to_file(self, file_name):
+                    Creates new notebook containing history of all executed cells of the current notebook. 
     """
 
     def __init__(self, user_token, project_id=None, server_url="http://localhost:5000", 
@@ -166,11 +170,32 @@ class LDMLogger():
             if (r.status_code != 200):
                 print("Error: " + r.json()['err'])
         except:
-            print("Unknown error in finish_run.")
+            print("Unknown error in validate.")
             print(sys.exc_info()[0])
             raise
 
 
+    def save_colab_notebook_history_to_file(self, file_name):
+        """ 
+        Use this function to save the history of executed cells in IPython notebook to a new notebook (file_name).
+      
+        Parameters: 
+
+        file_name (string): Path to file were notebook will be stored.
+      
+        Returns: 
+
+        None
+      
+        """
+        import sys
+        #print ('Running in colab:', 'google.colab' in sys.modules)
+        if 'google.colab' in sys.modules:
+            from IPython import get_ipython
+            ipython = get_ipython()
+            ipython.magic("notebook " + file_name)
+
+
     def upload_file(self, file_name, comment = ""):
         """ 
         Upload file (file_name) to the logging server and attaches it to the current run.
@@ -185,7 +210,7 @@ class LDMLogger():
 
         None
       
-        """    
+        """
 
         try:
             with open(file_name, 'rb') as f:
@@ -205,7 +230,19 @@ class LDMLogger():
 
 
     def upload_sources(self):
+        """ 
+        Creates a .zip of root_dir (passed in constructor) and uploads this .zip to the LDM server. 
+        In case if root_dir is None no action is performed (method exits immediately).
+      
+        Parameters: 
 
+        None
+      
+        Returns: 
+
+        None
+      
+        """
         # if self.root_dir is None, then no source code upload
         if (self.root_dir is None):
             return
